Version history
===============

This library adheres to `Semantic Versioning <http://semver.org/>`_.

**2.0.0** (2017-04-10)

- **BACKWARD INCOMPATIBLE** Migrated to Asphalt 3.0

**1.0.0** (2016-05-16)

- Initial release
